dmqclib.classify package
========================

.. automodule:: dmqclib.classify
   :members:
   :show-inheritance:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dmqclib.classify.step1_read_input
   dmqclib.classify.step2_calc_stats
   dmqclib.classify.step3_select_profiles
   dmqclib.classify.step4_select_rows
   dmqclib.classify.step5_extract_features
   dmqclib.classify.step6_classify_dataset
   dmqclib.classify.step7_concat_datasets
